#!/bin/sh
# project: http://www.sonicvisualiser.org
#
# script : til <rob DOT til DOT freedman AT googlemail DOT com>
#
set -x -e -u

pkgname=sonic-visualiser
pkgver=1.7.1

build=${build:-'64.1'}
arch=${arch:-i686}
cpu=pentium3
cpu=${cpu:-i686}

PKG_SRC="http://downloads.sourceforge.net/sv1/sonic-visualiser-${pkgver}.tar.bz2
http://zenwalk.pinguix.com/user-accounts/tilderb/extra/xap/sonic-visualiser/build-sonic-visualiser.sh"
PKG_DEP="alsa-lib,bzip2,curl,cxxlibs,cyrus-sasl,db44,expat,fftw,flac,fontconfig,freetype,glib2,glibc-solibs,gmp,jack,krb5,libICE,libSM,libX11,libXau,libXdmcp,libXext,libXrender,libfishsound,libid3tag,libidn,liblo,liblrdf,libmad,libogg,liboggz,libpng,libsamplerate,libsndfile,libvorbis,libxcb,libxml2,libxslt,mpfr,openldap-client,openssl,portaudio,qt,raptor,rasqal,redland,rubberband,speex,util-linux-ng,vamp-plugin-sdk,zlib"

package=${pkgname}-${pkgver}-${arch}-${build}

# tmp tree
CWD=`pwd`
TMP=${TMP:-$CWD}
PKG=$TMP/$package
SRC=$TMP/${pkgname}-${pkgver}

[ -d $PKG ] && rm -fr $PKG
[ -d $SRC ] && rm -fr $SRC

# prepare build directory
mkdir -p $PKG/{install,usr/bin,usr/{src,doc}/${pkgname}-${pkgver}}
mkdir -p $PKG/usr/share/{applications,icons/hicolor/{16x16,32x32,48x48,scalable}/apps}

tar xjf $CWD/${pkgname}-${pkgver}.tar.bz2 -C $TMP
cd $SRC

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

sed -i "s:-O3:-O2 -march=$arch -mtune=$cpu -msse -mmmx -ftree-vectorize -fomit-frame-pointer:g" prf/sv.prf

source /etc/profile.d/qt4.sh

qmake
make || exit 1

# strip symbols
strip --strip-unneeded sv/sonic-visualiser
cp sv/sonic-visualiser $PKG/usr/bin

# package docs
cp -a CHANGELOG INSTALL COPYING README* $PKG/usr/doc/${pkgname}-${pkgver}/

# copy icons
for size in 16x16 32x32 48x48; do
  cp sv/icons/sv-$size.png \
    $PKG/usr/share/icons/hicolor/${size}/apps/sonic-visualiser.png
done
  cp sv/icons/sv-icon.svg \
	$PKG/usr/share/icons/hicolor/scalable/apps/sonic-visualiser.svg

cd $PKG
# create desktop menu entry
cat <<EOF > usr/share/applications/$pkgname.desktop
[Desktop Entry]
Name=Sonic Visualiser
Comment=Audio Analysing Editor
Exec=sonic-visualiser
Icon=sonic-visualiser
Terminal=false
Categories=Qt;AudioVideo;Audio;Music
Type=Application
EOF

# create slack description
#               |-----handy-ruler-------------------------------------------------------|
cat <<EOF > install/slack-desc
sonic-visualiser: Sonic Visualiser (viewing and analysing music audio files)
sonic-visualiser:
sonic-visualiser: Sonic Visualiser is an application for viewing and analysing the
sonic-visualiser: contents of music audio files.
sonic-visualiser:
sonic-visualiser: The aim of Sonic Visualiser is to be the first program you reach for
sonic-visualiser: when want to study a musical recording rather than simply listen to it.
EOF

# doinst.sh
cat <<EOF >install/doinst.sh
#!/bin/sh
# sonic-visualiser 
[ -x usr/bin/gtk-update-icon-cache ] && \
    usr/bin/gtk-update-icon-cache -qf usr/share/icons/hicolor 
[ -x usr/bin/update-desktop-database ] && \
    usr/bin/update-desktop-database
EOF

# copy build script
cp $CWD/build-sonic-visualiser.sh usr/src/${pkgname}-${pkgver}

fakeroot /sbin/makepkg -l y -c n $CWD/$package.txz
cd $CWD
echo $PKG_DEP >$package.dep
#depfinder $PKG # >$package.dep
echo "$PKG_SRC" >$package.src
md5sum $package.txz >$package.md5
